@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 use Carp;
 use File::Find::Rule;
@@ -123,6 +123,10 @@ sub splice {
         croak "splice() requires insert => [aref] param";
     }
 
+    if (! defined $line && ! defined $find){
+        croak "splice() requires either the 'line' or 'find' parameter sent in.";
+    }
+
     if (defined $line && defined $find){
         warn
           "splice() can't search for both line and find. Operating on 'line'.";
@@ -200,8 +204,7 @@ sub recsep {
     my $file = shift;
     my $hex = shift if @_;
 
-    my $fh;
-
+    my $fh; 
     eval {
         $fh = $self->_open($file);
     };
@@ -403,7 +406,7 @@ sub DESTROY {
         }
     }
 }
-sub _vim_placeholder {}; # for folding
+sub _vim_placeholder { return 1; }; # for folding
 
 1;
 __END__
@@ -518,7 +521,7 @@ C<find =E<gt> 'search term'>: Optional - Merge the contents into the file on the
 
 C<limit =E<gt> Integer>: Optional: When splicing with the 'find' param, set this to the number of finds to insert after. Default is stop after the first find. Set to 0 will insert after all finds.
 
-NOTE: Although both are optional, at least one of C<line> or C<find> must be sent in.
+NOTE: Although both are optional, at least one of C<line> or C<find> must be sent in. If both are sent in, we'll warn, and operate on the line number and skip the find parameter.
 
 Returns an array of the modified file contents.  
 
@@ -575,7 +578,10 @@ L<https://github.com/stevieb9/file-edit-portable>
 
 =head1 BUILD RESULTS
 
-Travis-CI: L<https://travis-ci.org/stevieb9/file-edit-portable>
+=begin html
+<a href="http://travis-ci.org/stevieb9/file-edit-portable"><img src="https://secure.travis-ci.org/stevieb9/file-edit-portable.png"/>
+<a href='https://coveralls.io/github/stevieb9/file-edit-portable?branch=master'><img src='https://coveralls.io/repos/stevieb9/file-edit-portable/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
+=end html
 
 CPAN Testers: L<http://matrix.cpantesters.org/?dist=File-Edit-Portable>
 
@@ -604,7 +610,7 @@ L<http://search.cpan.org/dist/File-Edit-Portable/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015 Steve Bertrand.
+Copyright 2016 Steve Bertrand.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
